@@ -29,6 +29,10 @@ except ModuleNotFoundError:
     import version
 
 
+def reset():
+    connect_core.new_event_loop = list()
+
+
 class API:
     def __init__(
             self,
@@ -515,11 +519,10 @@ class API:
     def _get_newest_index(
             self,
             index_type: int,
-            board: str = None,
-            # BBS
             search_type: int = 0,
             search_condition: str = None,
-            search_list: list = None) -> int:
+            search_list: list = None,
+            board: str = None) -> int:
 
         check_value.check(
             self.config, int, 'index_type',
@@ -533,10 +536,10 @@ class API:
         return _api_get_newest_index.get_newest_index(
             self,
             index_type,
-            board,
             search_type,
             search_condition,
-            search_list)
+            search_list,
+            board)
 
     def get_newest_index(
             self,
@@ -551,21 +554,38 @@ class API:
             if not self._login_status:
                 raise exceptions.Requirelogin(i18n.Requirelogin)
 
+        if index_type == data_type.index_type.BBS:
+            check_value.check(
+                self.config, int, 'SearchType', search_type,
+                value_class=data_type.post_search_type)
+
         if index_type == data_type.index_type.MAIL:
             if self.unregistered_user:
                 raise exceptions.UnregisteredUser(lib_util.get_current_func_name())
 
+            check_value.check(
+                self.config, int, 'SearchType', search_type,
+                value_class=data_type.mail_search_type)
+
         self.config.log_last_value = None
 
-        try:
-            return self._get_newest_index(
-                index_type,
-                board,
-                search_type,
-                search_condition,
-                search_list)
-        except exceptions.NoSearchResult:
-            raise exceptions.NoSearchResult
+        if search_condition is not None:
+            check_value.check(
+                self.config, str,
+                'SearchCondition', search_condition)
+
+        if search_list is not None:
+            check_value.check(
+                self.config, list,
+                'search_list', search_list)
+        check_value.check(self.config, int, 'SearchType', search_type)
+
+        return self._get_newest_index(
+            index_type,
+            search_type,
+            search_condition,
+            search_list,
+            board)
 
     def crawl_board(
             self,
@@ -1302,7 +1322,8 @@ class API:
             ptt_id: str,
             title: str,
             content: str,
-            sign_file) -> None:
+            sign_file,
+            backup: bool = True) -> None:
         self._one_thread()
 
         if not self._login_status:
@@ -1346,7 +1367,8 @@ class API:
             ptt_id,
             title,
             content,
-            sign_file)
+            sign_file,
+            backup)
 
         if self._mailbox_full:
             self.logout()
@@ -1629,7 +1651,12 @@ class API:
 
         return _api_get_board_info.get_board_info(self, board, get_post_kind, call_by_others)
 
-    def get_mail(self, index):
+    def get_mail(
+            self,
+            index: int,
+            search_type: int = 0,
+            search_condition: str = None,
+            search_list: list = None):
 
         self._one_thread()
 
@@ -1651,7 +1678,12 @@ class API:
         except ModuleNotFoundError:
             import _api_mail
 
-        return _api_mail.get_mail(self, index)
+        return _api_mail.get_mail(
+            self,
+            index,
+            search_type,
+            search_condition,
+            search_list)
 
     def del_mail(self, index):
         self._one_thread()
@@ -1875,7 +1907,6 @@ class API:
         self.connect_core.send(cmd, target_list, refresh=current_refresh)
 
         if end:
-
             cmd_list = list()
             cmd_list.append('1')
             cmd_list.append(command.Enter)
